@@ -1,4 +1,4 @@
-/* $Id: Sybase.h,v 1.19 2011/04/25 08:59:17 mpeppler Exp $
+/* $Id: Sybase.h,v 1.21 2011/10/02 14:53:49 mpeppler Exp $
 
    Copyright (c) 1997 - 2011 Michael Peppler
 
@@ -52,6 +52,15 @@
 #if defined(CS_CURRENT_VERSION)
 #define CTLIB_VERSION	CS_CURRENT_VERSION
 #else
+#if defined(CS_VERSION_157)
+#define CTLIB_VERSION   CS_VERSION_157
+#else 
+#if defined(CS_VERSION_155)
+#define CTLIB_VERSION   CS_VERSION_155
+#else 
+#if defined(CS_VERSION_150)
+#define CTLIB_VERSION   CS_VERSION_150
+#else 
 #if defined(CS_VERSION_125)
 #define CTLIB_VERSION   CS_VERSION_125
 #else 
@@ -66,8 +75,11 @@
 #endif
 #endif
 #endif
+#endif
+#endif
+#endif
 
-#if defined(CS_UNICHAR_TYPE)
+#if defined(CS_UNICHAR_TYPE) && defined(CS_VERSION_150)
 #if defined (is_utf8_string)
 #define DBD_CAN_HANDLE_UTF8
 #endif
@@ -110,11 +122,11 @@ void     syb_st_destroy _((SV *sth, imp_sth_t *imp_sth));
 int      syb_st_blob_read _((SV *sth, imp_sth_t *imp_sth,
                 int field, long offset, long len, SV *destrv, long destoffset));
 int      syb_ct_get_data _((SV *sth, imp_sth_t *imp_sth, 
-			    int column, SV *bufrv, int buflen));
+                int column, SV *bufrv, int buflen));
 int      syb_ct_data_info _((SV *sth, imp_sth_t *imp_sth, int action, 
-			     int column, SV *attr));
+               int column, SV *attr));
 int      syb_ct_send_data _((SV *sth, imp_sth_t *imp_sth, char *buffer, 
-			     int size));
+               int size));
 int      syb_ct_prepare_send _((SV *sth, imp_sth_t *));
 int      syb_ct_finish_send _((SV *sth, imp_sth_t *));
 int      syb_st_STORE_attrib _((SV *sth, imp_sth_t *imp_sth, SV *keysv, SV *valuesv));
@@ -123,7 +135,7 @@ SV      *syb_st_FETCH_attrib _((SV *sth, imp_sth_t *imp_sth, SV *keysv));
 int      syb_describe _((SV *sth, imp_sth_t *imp_sth));
 int      syb_bind_ph  _((SV *sth, imp_sth_t *imp_sth,
                 SV *param, SV *value, IV sql_type, SV *attribs,
-				int is_inout, IV maxlen));
+                int is_inout, IV maxlen));
 
 
 /* prototypes for module-specific functions */
